ThreadLocalScope

com.softwaremill.macwire.scopes.ThreadLocalScope

Attributes

Graph
Supertypes
trait Scope
class Object
trait Matchable
class Any
Show all

Members list

Value members

Inherited methods

def apply[T](createT: => T)(implicit tag: ClassTag[T]): T

Create a scoped value with the given factory class.

Create a scoped value with the given factory class.

Attributes

Inherited from:
ProxyingScope
def associate(storage: Map[String, Any]): Unit

Attributes

Inherited from:
ThreadLocalScopeStorage
def associate(storage: Map[String, Any]): Unit

Attributes

Inherited from:
ThreadLocalScopeStorage
def associate(storage: ScopeStorage): Unit

Attributes

Inherited from:
ThreadLocalScopeStorage

Attributes

Inherited from:
ThreadLocalScopeStorage
def disassociate(): Unit

Attributes

Inherited from:
ThreadLocalScopeStorage
def get[T](key: String, createT: => T): T

Get an instance from the current scope, for the specified key, using the given factory class to create an instance if not yet created.

Get an instance from the current scope, for the specified key, using the given factory class to create an instance if not yet created.

Attributes

Inherited from:
ThreadLocalScopeStorage
def withEmptyStorage[T](body: => T): T

Attributes

Inherited from:
ThreadLocalScopeStorage
def withStorage[T](storage: Map[String, Any])(body: => T): T

Attributes

Inherited from:
ThreadLocalScopeStorage
def withStorage[T](storage: Map[String, Any])(body: => T): T

Attributes

Inherited from:
ThreadLocalScopeStorage
def withStorage[T](storage: ScopeStorage)(body: => T): T

Attributes

Inherited from:
ThreadLocalScopeStorage