ThreadLocalScope
com.softwaremill.macwire.scopes.ThreadLocalScope
class ThreadLocalScope extends ProxyingScope, ThreadLocalScopeStorage
Attributes
- Graph
-
- Supertypes
-
trait ThreadLocalScopeStoragetrait ProxyingScopetrait Scopeclass Objecttrait Matchableclass AnyShow all
Members list
Value members
Inherited methods
Create a scoped value with the given factory class.
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Get an instance from the current scope, for the specified key, using the given factory class to create an instance if not yet created.
Get an instance from the current scope, for the specified key, using the given factory class to create an instance if not yet created.
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
Attributes
- Inherited from:
- ThreadLocalScopeStorage
In this article